package main

import (
	"fmt"
	"log"
	"net/rpc"
	"os"
	"strconv"

	"rpc_arith/arith" //Path to the package which contains service definition
)

func main() {

	addr := "localhost:" + "12345" //address and port on which RPC server is listening
	// Try to connect to addr
	client, err := rpc.Dial("tcp", addr)
	if err != nil {
		log.Fatal("Error in dialing: ", err)
	}
	defer client.Close()

	if len(os.Args) < 3 {
		fmt.Printf("No args passed in\n")
		os.Exit(1)
	}

	n1, _ := strconv.Atoi(os.Args[1])
	n2, _ := strconv.Atoi(os.Args[2])

	// Synchronous call
	args := &arith.Args{n1, n2}
	// reply will store the RPC result
	var mulReply arith.Result
	// Call remote procedure
	log.Printf("Synchronous call to RPC server")
	err = client.Call("Arithmetic.Multiply", args, &mulReply)
	if err != nil {
		log.Fatal("Error in Arithmetic.Multiply: ", err)
	}
	fmt.Printf("Arithmetic.Multiply: %d*%d=%d\n\n", args.A, args.B, mulReply)

	// Asynchronous call
	divReply := new(arith.Quotient)
	log.Printf("Asynchronous call to RPC server")
	divCall := client.Go("Arithmetic.Divide", args, divReply, nil)
	divCall = <-divCall.Done
	if divCall.Error != nil {
		log.Fatal("Error in Arithmetic.Divide: ", divCall.Error.Error())
	}
	fmt.Printf("Arithmetic.Divide: %d/%d=%d (rem=%d)\n", args.A, args.B, divReply.Quo, divReply.Rem)
}
