package main

import (
	"log"
	"net"
	"net/http"
	"net/rpc"

	"rpc_arith/arith" //Path to the package which contains service definition
)

func main() {

	//Create an instance of struct which implements Arith interface
	arith := new(arith.Arith)

	// Register a new RPC server and the struct we created above.
	// Only structs which implement Arith interface
	// are allowed to register themselves
	server := rpc.NewServer()
	err := server.RegisterName("Arithmetic", arith)
	if err != nil {
		log.Fatal("Format of service Arith is not correct: ", err)
	}
	// Register an HTTP handler for RPC messages on rpcPath, and a debugging handler on debugPath
	server.HandleHTTP("/", "/debug")

	// Listen for incoming messages on port 12345
	lis, err := net.Listen("tcp", ":12345")
	if err != nil {
		log.Fatal("Listen error: ", err)
	}
	log.Printf("RPC server on port %d", 12345)

	// Start go's http server on socket specified by listener
	err = http.Serve(lis, nil)
	if err != nil {
		log.Fatal("Serve error: ", err)
	}
}
