package main

import (
	"log"
	"net"
	"net/rpc"

	"rpc_arith/arith" //Path to the package which contains service definition
)

func main() {

	//Create an instance of struct which implements Arith interface
	arith := new(arith.Arith)

	// Register a new rpc server and the struct we created above.
	// Only structs which implement Arith interface
	// are allowed to register themselves
	server := rpc.NewServer()
	err := server.RegisterName("Arithmetic", arith)
	if err != nil {
		log.Fatal("Format of service Arith is not correct: ", err)
	}

	// Listen for incoming TCP packets on specified port
	lis, err := net.Listen("tcp", ":12345")
	if err != nil {
		log.Fatal("Error in listening:", err)
	}
	log.Printf("RPC server on port %d", 12345)

	// Allow RPC server to accept requests connections on the listener
	// and serve requests for each incoming connection
	server.Accept(lis)
}
